#!perl -T

use Test::More tests => 1;

BEGIN {
	use_ok( 'Rose::HTMLx::Form::Field::Boolean' );
}

diag( "Testing Rose::HTMLx::Form::Field::Boolean $Rose::HTMLx::Form::Field::Boolean::VERSION, Perl $], $^X" );
